=================================
education_math_homework_generator
=================================


.. image:: https://img.shields.io/pypi/v/education_math_homework_generator.svg
        :target: https://pypi.python.org/pypi/education_math_homework_generator

.. image:: https://img.shields.io/travis/physbean/education_math_homework_generator.svg
        :target: https://travis-ci.com/physbean/education_math_homework_generator

.. image:: https://readthedocs.org/projects/education-math-homework-generator/badge/?version=latest
        :target: https://education-math-homework-generator.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Simple, scalable addition and subtraction homework generator using python and latex to create clean pdfs for early childhood 


* Free software: MIT license
* Documentation: https://education-math-homework-generator.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
